@@ -22,9 +22,9 @@ class FloatColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         :param options: Options for the float column
         :type options: FloatOptions
         """
-        if options:
-            if not isinstance(options, FloatOptions):
-                raise ValueError("options must be of type FloatOptions.")
+        if options and not isinstance(options, FloatOptions):
+            raise ValueError("FloatColumn parameter 'options' must be of type"
+                             " FloatOptions.")
         NumericStatsMixin.__init__(self, options)
         BaseColumnPrimitiveTypeProfiler.__init__(self, name)
         self.precision = 0
@@ -50,6 +50,14 @@ class FloatColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         merged_profile = FloatColumn(None)
         BaseColumnPrimitiveTypeProfiler._add_helper(merged_profile, self, other)
         NumericStatsMixin._add_helper(merged_profile, self, other)
+        
+        self._merge_calculations(merged_profile.__calculations,
+                                 self.__calculations,
+                                 other.__calculations)
+
+        if "precision" in merged_profile.__calculations:
+            merged_profile.precision = min(self.precision, other.precision)
+            
         return merged_profile
 
     @property
@@ -88,31 +96,49 @@ class FloatColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         return None
 
     @classmethod
-    def _get_float_precision(cls, df_series):
+    def _get_float_precision(cls, df_series_clean):
         """
-        Determines the precision of the numeric value
-        :param df_series: a given column
-        :type df_series: pandas.core.series.Series
+        Determines the precision of the numeric value.
+        
+        :param df_series_clean: df series with nulls removed, assumes all values
+            are floats as well
+        :type df_series_clean: pandas.core.series.Series
         :return: string representing its precision print format
         :rtype: int
         """
-        integer_decimal_loc = -1
-        float_precision = 0
-        for value in df_series:
-            decimal_loc = value.rfind('.')
+        if not len(df_series_clean):
+            return 0
 
-            # integers will not have a '.'
-            if decimal_loc == integer_decimal_loc:
-                continue
+        # set it to first value length, at very least will be smaller since min.
+        precision = len(df_series_clean.iloc[0])
+        for value in df_series_clean:
 
-            # since has a '.', subtract the str len from the position,
-            # since indexes start at 0: len - pos - 1
-            value_len = len(value)
-            value_precision = value_len - decimal_loc - 1
+            # remove all spaces around value
+            value = value.strip()
 
-            if float_precision < value_precision:
-                float_precision = value_precision
-        return float_precision
+            # if scientific notation, remove e and everything after
+            e_ind = value.find('e')
+            if e_ind > -1:
+                value = value[:e_ind]
+
+            # remove negative of positive characters
+            if value[0] in ['+', '-']:
+                value = value[1:]
+
+            # if int: remove 0s on right, otherwise if float remove the decimal.
+            if '.' not in value:
+                value = value.rstrip('0')
+            else:
+                value = value.replace('.', '')
+
+            # strip all zeros on left
+            value = value.lstrip('0')
+            temp_precision = len(value)
+
+            # take the minimum precision
+            if temp_precision < precision:
+                precision = temp_precision
+        return precision
 
     @classmethod
     def _is_each_row_float(cls, df_series):
@@ -150,9 +176,11 @@ class FloatColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         :type df_series: pandas.DataFrame
         :return: None
         """
-        self.precision = max(
-            self.precision, self._get_float_precision(df_series)
-        )
+        subset_precision = self._get_float_precision(df_series)
+        if self.precision and subset_precision:
+            self.precision = min(self.precision, subset_precision)
+        elif subset_precision:
+            self.precision = subset_precision
 
     def _update_helper(self, df_series_clean, profile):
         """
