@@ -130,40 +130,44 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):
         :param other2: profile2 being added to self
         :return: None
         """
-        # Merge Variance
-        self.variance = self._merge_variance(
-            other1.match_count, other1.variance, other1.mean,
-            other2.match_count, other2.variance, other2.mean)
 
-        # Merge min, max, sum and histograms
-        if other1.min is not None and other2.min is not None:
-            # update histogram
-            self._add_helper_merge_profile_histograms(other1, other2)
+        BaseColumnProfiler._merge_calculations(
+            self._NumericStatsMixin__calculations,
+            other1._NumericStatsMixin__calculations,
+            other2._NumericStatsMixin__calculations)
 
-            # update min, max, sum
-            self.min = min(other1.min, other2.min)
-            self.max = max(other1.max, other2.max)
+        # Merge variance, histogram, min, max, and sum
+        if "variance" in self.__calculations.keys():
+            self.variance = self._merge_variance(
+                other1.match_count, other1.variance, other1.mean,
+                other2.match_count, other2.variance, other2.mean)
+        if "histogram_and_quantiles" in self.__calculations.keys():
+            if other1.histogram_selection is not None and \
+                    other2.histogram_selection is not None:
+                self._add_helper_merge_profile_histograms(other1, other2)
+            elif other2.histogram_selection is None:
+                self.histogram_methods = other1.histogram_methods
+                self.quantiles = other1.quantiles
+            else:
+                self.histogram_methods = other2.histogram_methods
+                self.quantiles = other2.quantiles
+        if "min" in self.__calculations.keys():
+            if other1.min is not None and other2.min is not None:
+                self.min = min(other1.min, other2.min)
+            elif other2.min is None:
+                self.min = other1.min
+            else:
+                self.min = other2.min
+        if "max" in self.__calculations.keys():
+            if other1.max is not None and other2.max is not None:
+                self.max = max(other1.max, other2.max)
+            elif other2.max is None:
+                self.max = other1.max
+            else:
+                self.max = other2.max
+        if "sum" in self.__calculations.keys():
             self.sum = other1.sum + other2.sum
 
-        elif other2.min is None:
-            # update histogram
-            self.histogram_methods = other1.histogram_methods
-            self.quantiles = other1.quantiles
-
-            # update min, max, sum
-            self.min = other1.min
-            self.max = other1.max
-            self.sum = other1.sum
-        else:
-            # update histogram
-            self.histogram_methods = other2.histogram_methods
-            self.quantiles = other2.quantiles
-
-            # update min, max, sum
-            self.min = other2.min
-            self.max = other2.max
-            self.sum = other2.sum
-
     @property
     def mean(self):
         if self.match_count == 0:
