@@ -5,6 +5,7 @@ import random
 import pkg_resources
 import json
 from io import StringIO
+import re
 
 import numpy as np
 
@@ -519,12 +520,12 @@ class TestCharPreprocessor(unittest.TestCase):
         # test a single sentence
         test_sentences = np.array(['this is my test sentence. How nice.'])
         labels = [
-            dict(entities=[
+            [
                 [5, 7, 'TEST1'],
                 [11, 24, 'TEST2'],
                 [26, 29, 'TEST1'],
                 [30, 34, 'TEST2']
-            ])
+            ]
         ]
         expected_output = [
             dict(samples=['this', ' is'],
@@ -550,8 +551,8 @@ class TestCharPreprocessor(unittest.TestCase):
         # ' How'  -> 'How'
         test_sentences = np.array(['this is my test sentence.', 'How nice.'])
         labels = [
-            dict(entities=[[5, 7, 'TEST1'], [11, 24, 'TEST2']]),
-            dict(entities=[[0, 3, 'TEST1'], [4, 8, 'TEST2']])
+            [[5, 7, 'TEST1'], [11, 24, 'TEST2']],
+            [[0, 3, 'TEST1'], [4, 8, 'TEST2']]
         ]
         expected_output = [
             dict(samples=['this', ' is'],
@@ -601,7 +602,8 @@ class TestCharPreprocessor(unittest.TestCase):
                                     'If `labels` are specified, `label_mapping`'
                                     ' must also be specified'):
             process_generator = preprocessor.process(
-                ['test'], labels=['test'], label_mapping=None, batch_size=2)
+                np.array(['test']), labels=['test'], label_mapping=None,
+                batch_size=2)
             next(process_generator)
 
         # test a single sentence
@@ -626,12 +628,12 @@ class TestCharPreprocessor(unittest.TestCase):
         # with labels process
         test_sentences = np.array(['this is my'])
         labels = [
-            dict(entities=[
+            [
                 [5, 7, 'TEST1'],
                 [11, 24, 'TEST2'],
                 [26, 29, 'TEST1'],
                 [30, 34, 'TEST2']
-            ])
+            ]
         ]
         expected_sentence_output = [
             [['this'], [' is']],
@@ -671,6 +673,22 @@ class TestCharPreprocessor(unittest.TestCase):
             self.assertTrue((expected[0] == output[0]).all())
             self.assertTrue((expected[1] == output[1]).all())
 
+    def test_process_input_checks(self):
+        prep = CharPreprocessor()
+        multi_dim_msg = re.escape("Multidimensional data given to "
+                                  "CharPreprocessor. Consider using a different"
+                                  " preprocessor or flattening data (and labels)")
+        with self.assertRaisesRegex(ValueError, multi_dim_msg):
+            next(prep.process(np.array([["this", "is"],
+                                        ["two", "dimensions"]])))
+        diff_length_msg = re.escape("Data and labels given to CharPreprocessor "
+                                    "are different lengths, 2 != 1")
+        with self.assertRaisesRegex(ValueError, diff_length_msg):
+            next(prep.process(np.array(["two", "strings"]),
+                              np.array([[(0, 1, "BACKGROUND")]],
+                                       dtype="object"),
+                              {"BACKGROUND": 1}))
+
 
 class TestCharPostprocessor(unittest.TestCase):
 
@@ -1482,7 +1500,7 @@ class TestStructCharPreprocessor(unittest.TestCase):
         test_array = np.array(['this', ' is', 'my test sentence.', ' How ',
                                'nice.'])
         labels = ['TEST1', 'TEST2', 'BACKGROUND', 'TEST2', 'TEST1']
-        expected_labels = dict(entities=[
+        expected_labels = [
             (0, 4, 'TEST1'),
             (4, 9, 'PAD'),
             (9, 12, 'TEST2'),
@@ -1491,14 +1509,14 @@ class TestStructCharPreprocessor(unittest.TestCase):
             (39, 44, 'TEST2'),
             (44, 49, 'PAD'),
             (49, 54, 'TEST1'),
-        ])
+        ]
 
         output_text, output_labels = \
             preprocessor.convert_to_unstructured_format(
                 test_array, labels=labels)
 
         self.assertEqual(expected_text, output_text)
-        self.assertDictEqual(expected_labels, output_labels)
+        self.assertEqual(expected_labels, output_labels)
 
     def test_process(self):
         preprocessor = StructCharPreprocessor(
@@ -1528,7 +1546,8 @@ class TestStructCharPreprocessor(unittest.TestCase):
                                     'If `labels` are specified, `label_mapping`'
                                     ' must also be specified'):
             process_generator = preprocessor.process(
-                ['test'], labels=['test'], label_mapping=None, batch_size=2)
+                np.array(['test']), labels=np.array(['test']),
+                label_mapping=None, batch_size=2)
             next(process_generator)
 
         # test a single sentence
@@ -1551,7 +1570,7 @@ class TestStructCharPreprocessor(unittest.TestCase):
 
         # with labels process
         test_array = np.array(['this', ' is', 'my test.'])
-        labels = ['TEST1', 'TEST2', 'BACKGROUND']
+        labels = np.array(['TEST1', 'TEST2', 'BACKGROUND'])
         expected_sentence_output = [
             np.array([['this'], [' is' + separator + 'my']]),
             np.array([[' test.']]),
@@ -1607,6 +1626,23 @@ class TestStructCharPreprocessor(unittest.TestCase):
             self.assertTrue((expected[0] == output[0]).all())
             self.assertTrue((expected[1] == output[1]).all())
 
+    def test_process_input_checks(self):
+        prep = StructCharPreprocessor()
+        diff_shape_msg = re.escape("Data and labels given to "
+                                   "StructCharPreprocessor are of different "
+                                   "shapes, (2, 1) != (1, 2)")
+        with self.assertRaisesRegex(ValueError, diff_shape_msg):
+            prep.process(np.array([["hello"], ["world"]]),
+                         np.array([["BACKGROUND", "BACKGROUND"]]),
+                         {"BACKGROUND": 1})
+        multi_dim_msg = re.escape("Data given to StructCharPreprocessor was "
+                                  "multidimensional, it will be flattened for "
+                                  "model processing. Results may be inaccurate,"
+                                  " consider reformatting data or changing "
+                                  "preprocessor.")
+        with self.assertWarnsRegex(Warning, multi_dim_msg):
+            prep.process(np.array([["this", "is"], ["two", "dimensions"]]))
+
 
 class TestStructCharPostprocessor(unittest.TestCase):
 
